@@ -4,6 +4,8 @@ $results="../popcon-mail/results";
 $popcon="../www";
 my $mirrorbase = "/org/ftp.root/debian";
 my $docurlbase = "";
+%popconver=("1.28" => "sarge", "1.41" => "etch", "1.46" => "lenny");
+%popver=();
 
 sub htmlheader
 {
@@ -204,7 +206,7 @@ sub mark
 @fields=("inst","vote","old","recent","no-files");
 
 for $file ("slink","slink-nonUS","potato","potato-nonUS",
-           "woody","woody-nonUS","sarge")
+           "woody","woody-nonUS","sarge","etch")
 {
   open AVAIL, "<:utf8", "$file.sections" or die "Cannot open $file.sections";
   while(<AVAIL>)
@@ -222,25 +224,35 @@ for $file ("slink","slink-nonUS","potato","potato-nonUS",
 mark "Reading legacy packages...";
 $ENV{PATH}="/bin:/usr/bin";
 
-for (glob("/org/ftp.root/debian/dists/stable/*/binary-*/Packages.gz"),
-           glob("/org/ftp.root/debian/dists/testing/*/binary-*/Packages.gz"),
-           glob("/org/ftp.root/debian/dists/sid/*/binary-*/Packages.gz"))
+for $dist ("stable", "testing", "unstable")
 {
-  /([^[:space:]]+)/ or die("incorrect package name");
-  $file = $1;#Untaint
-  open AVAIL, "-|:encoding(UTF-8)","zcat $file";
-  while(<AVAIL>)
+  for (glob("$mirrorbase/dists/$dist/*/binary-*/Packages.gz"))
   {
-/^Package: (.+)/  and do {$p=$1;$maint{$p}="bug";$source{$p}=$p;next;};
-/^Maintainer: ([^()]+) (\(.+\) )*<.+>/ and do { $maint{$p}=join(' ',map{ucfirst($_)} split(' ',lc $1));next;};
-/^Source: (\S+)/ and do { $source{$p}=$1;next;};
-/^Section: (.+)/ or next;
-          $sec=$1;
-          $sec =~ m{^(non-US|contrib|non-free)/} or $sec="main/$sec";
-          $section{$p}=$sec;
+    /([^[:space:]]+)/ or die("incorrect package name");
+    $file = $1;#Untaint
+    open AVAIL, "-|:encoding(UTF-8)","zcat $file";
+    while(<AVAIL>)
+    {
+  /^Package: (.+)/  and do {$p=$1;$maint{$p}="bug";$source{$p}=$p;next;};
+  /^Version: (.+)/ && $p eq "popularity-contest" 
+        and do { $popver{$dist}=$1; next;};
+  /^Maintainer: ([^()]+) (\(.+\) )*<.+>/
+        and do { $maint{$p}=join(' ',map{ucfirst($_)} split(' ',lc $1));next;};
+  /^Source: (\S+)/ and do { $source{$p}=$1;next;};
+  /^Section: (.+)/ or next;
+            $sec=$1;
+            $sec =~ m{^(non-US|contrib|non-free)/} or $sec="main/$sec";
+            $section{$p}=$sec;
+    }
+    close AVAIL;
   }
-  close AVAIL;
 }
+for $dist ("stable", "testing", "unstable")
+{
+  my($v)=$popver{$dist};
+  $popconver{$v}=defined($popconver{$v})?"$popconver{$v}/$dist":$dist;
+}
+
 mark "Reading current packages...";
 
 
@@ -429,8 +441,16 @@ EOF
 	print HTML  <<'EOF';
 </pre></td>
 <td>
+<table>
+  <tr><td>
  <img alt="Graph of number of submissions per architectures"
  width="600" height="400" src="stat/submission.png">
+  </td></tr>
+  <tr><td>
+ <img alt="Graph of number of submissions per architectures (last 12 months)"
+ width="600" height="400" src="stat/submission-1year.png">
+  </td></tr>
+</table>
 </td></tr>
 <tr><td>
 Statistics per popularity-contest releases:
@@ -438,17 +458,28 @@ Statistics per popularity-contest releases:
 EOF
         for $f (grep { $_ ne 'unknown' } sort keys %release)
         {
-                printf HTML "%-16s : %-10s \n",$f,$release{$f};
+                my($name) = $f;
+                $name = "$f ($popconver{$f})" if (defined($popconver{$f}));
+                printf HTML "%-25s : %-10s \n",$name,$release{$f};
         }
         if (defined $release{"unknown"}) {
-            printf HTML "%-16s : %-10s \n","unknown",$release{"unknown"};
+            printf HTML "%-25s : %-10s \n","unknown",$release{"unknown"};
         }
 	print HTML  <<'EOF';
 </pre></td>
 <td>
- <img alt="Graph of popularity-contest versions in use"
-  width="600" height="400" src="stat/release.png">
-</td></tr>
+<table>
+  <tr><td>
+   <img alt="Graph of popularity-contest versions in use"
+    width="600" height="400" src="stat/release.png">
+  </td></tr>
+  <tr><td>
+ <img alt="Graph of popularity-contest versions in use (12 last months)"
+  width="600" height="400" src="stat/release-1year.png">
+  </td></tr>
+</table>
+</td>
+</tr>
 </table>
 <p>
 EOF
